@@ -14,20 +14,22 @@
 #define TOR_BRIDGES_PRIVATE
 
 #include "core/or/or.h"
-#include "feature/client/bridges.h"
-#include "core/or/circuitbuild.h"
 #include "app/config/config.h"
 #include "core/mainloop/connection.h"
-#include "feature/dircache/directory.h"
-#include "feature/client/entrynodes.h"
-#include "feature/nodelist/nodelist.h"
+#include "core/or/circuitbuild.h"
 #include "core/or/policies.h"
-#include "feature/relay/router.h"
-#include "feature/nodelist/dirlist.h"
-#include "feature/nodelist/routerlist.h"
-
-#include "feature/nodelist/routerset.h"
+#include "feature/client/bridges.h"
+#include "feature/client/entrynodes.h"
 #include "feature/client/transports.h"
+#include "feature/dirclient/dirclient.h"
+#include "feature/dirclient/dlstatus.h"
+#include "feature/dircommon/directory.h"
+#include "feature/nodelist/describe.h"
+#include "feature/nodelist/dirlist.h"
+#include "feature/nodelist/nodelist.h"
+#include "feature/nodelist/routerinfo.h"
+#include "feature/nodelist/routerlist.h"
+#include "feature/nodelist/routerset.h"
 
 #include "core/or/extend_info_st.h"
 #include "feature/nodelist/node_st.h"
