@@ -12,19 +12,20 @@
 
 #include "lib/fdio/fdio.h"
 
-#include "core/or/circuitbuild.h"
 #include "app/config/config.h"
-#include "feature/dircache/directory.h"
-#include "feature/dircache/dirserv.h"
+#include "core/or/circuitbuild.h"
+#include "core/or/policies.h"
 #include "feature/client/entrynodes.h"
+#include "feature/dircache/dirserv.h"
+#include "feature/dirclient/dlstatus.h"
+#include "feature/dircommon/directory.h"
+#include "feature/dirparse/microdesc_parse.h"
+#include "feature/nodelist/dirlist.h"
 #include "feature/nodelist/microdesc.h"
 #include "feature/nodelist/networkstatus.h"
 #include "feature/nodelist/nodelist.h"
-#include "core/or/policies.h"
-#include "feature/relay/router.h"
-#include "feature/nodelist/dirlist.h"
 #include "feature/nodelist/routerlist.h"
-#include "feature/nodelist/routerparse.h"
+#include "feature/relay/router.h"
 
 #include "feature/nodelist/microdesc_st.h"
 #include "feature/nodelist/networkstatus_st.h"
