@@ -444,7 +444,7 @@ tor_tls_release_socket(tor_tls_t *tls)
    */
   tor_socket_t sock =
     tor_open_socket_nonblocking(AF_INET, SOCK_STREAM, IPPROTO_TCP);
-  if (!sock) {
+  if (! SOCKET_OK(sock)) {
     log_warn(LD_NET, "Out of sockets when trying to shut down an NSS "
              "connection");
     return;
@@ -452,10 +452,14 @@ tor_tls_release_socket(tor_tls_t *tls)
 
   PRFileDesc *tcp = PR_GetIdentitiesLayer(tls->ssl, PR_NSPR_IO_LAYER);
   if (BUG(! tcp)) {
+    tor_close_socket(sock);
     return;
   }
 
   PR_ChangeFileDescNativeHandle(tcp, sock);
+  /* Tell our socket accounting layer that we don't own this socket any more:
+   * NSS is about to free it for us. */
+  tor_release_socket_ownership(sock);
 }
 
 void
